@@ -12,10 +12,11 @@ main (void)
       gsl_vector_set (v, i, 1.23 + i);
     }
   
-  for (i = 0; i < 100; i++)
+  for (i = 0; i < 100; i++) /* OUT OF RANGE ERROR */
     {
       printf ("v_%d = %g\n", i, gsl_vector_get (v, i));
     }
 
+  gsl_vector_free (v);
   return 0;
 }
