@@ -4,7 +4,7 @@
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or (at
+ * the Free Software Foundation; either version 3 of the License, or (at
  * your option) any later version.
  * 
  * This program is distributed in the hope that it will be useful, but
@@ -14,7 +14,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include <config.h>
@@ -89,7 +89,7 @@ polynomial_eval (const void *vstate,
                  const double xa[], const double ya[], size_t size, double x,
                  gsl_interp_accel * acc, double *y)
 {
-  polynomial_state_t *state = (polynomial_state_t *) vstate;
+  const polynomial_state_t *state = (const polynomial_state_t *) vstate;
 
   *y = gsl_poly_dd_eval (state->d, xa, size, x);
 
@@ -102,7 +102,7 @@ polynomial_deriv (const void *vstate,
                   const double xa[], const double ya[], size_t size, double x,
                   gsl_interp_accel * acc, double *y)
 {
-  polynomial_state_t *state = (polynomial_state_t *) vstate;
+  const polynomial_state_t *state = (const polynomial_state_t *) vstate;
 
   gsl_poly_dd_taylor (state->coeff, x, state->d, xa, size, state->work);
 
@@ -116,7 +116,7 @@ polynomial_deriv2 (const void *vstate,
                    const double xa[], const double ya[], size_t size,
                    double x, gsl_interp_accel * acc, double *y)
 {
-  polynomial_state_t *state = (polynomial_state_t *) vstate;
+  const polynomial_state_t *state = (const polynomial_state_t *) vstate;
 
   gsl_poly_dd_taylor (state->coeff, x, state->d, xa, size, state->work);
 
@@ -130,7 +130,7 @@ polynomial_integ (const void *vstate, const double xa[], const double ya[],
                   size_t size, gsl_interp_accel * acc, double a, double b,
                   double *result)
 {
-  polynomial_state_t *state = (polynomial_state_t *) vstate;
+  const polynomial_state_t *state = (const polynomial_state_t *) vstate;
   size_t i;
   double sum;
 
