@@ -46,9 +46,32 @@ static double cholesky_norm1(const gsl_matrix * LLT, gsl_vector * work);
 static int cholesky_Ainv(CBLAS_TRANSPOSE_t TransA, gsl_vector * x, void * params);
 
 /*
-gsl_linalg_cholesky_decomp()
+In GSL 2.2, we decided to modify the behavior of the Cholesky decomposition
+to store the Cholesky factor in the lower triangle, and store the original
+matrix in the upper triangle. Previous versions stored the Cholesky factor in
+both places. The routine gsl_linalg_cholesky_decomp1 was added for the new
+behavior, and gsl_linalg_cholesky_decomp is maintained for backward compatibility.
+It will be removed in a future release.
+*/
+
+int
+gsl_linalg_cholesky_decomp (gsl_matrix * A)
+{
+  int status;
+
+  status = gsl_linalg_cholesky_decomp1(A);
+  if (status == GSL_SUCCESS)
+    {
+      gsl_matrix_transpose_tricpy('L', 0, A, A);
+    }
+
+  return status;
+}
+
+/*
+gsl_linalg_cholesky_decomp1()
   Perform Cholesky decomposition of a symmetric positive
-definite matrix
+definite matrix using lower triangle
 
 Inputs: A - (input) symmetric, positive definite matrix
             (output) lower triangle contains Cholesky factor
@@ -58,10 +81,12 @@ Return: success/error
 Notes:
 1) Based on algorithm 4.2.1 (Gaxpy Cholesky) of Golub and
 Van Loan, Matrix Computations (4th ed).
+
+2) original matrix is saved in upper triangle on output
 */
 
 int
-gsl_linalg_cholesky_decomp (gsl_matrix * A)
+gsl_linalg_cholesky_decomp1 (gsl_matrix * A)
 {
   const size_t M = A->size1;
   const size_t N = A->size2;
@@ -74,6 +99,9 @@ gsl_linalg_cholesky_decomp (gsl_matrix * A)
     {
       size_t j;
 
+      /* save original matrix in upper triangle for later rcond calculation */
+      gsl_matrix_transpose_tricpy('L', 0, A, A);
+
       for (j = 0; j < N; ++j)
         {
           double ajj;
@@ -231,7 +259,7 @@ gsl_linalg_cholesky_decomp_unit(gsl_matrix * A, gsl_vector * D)
   size_t i, j;
 
   /* initial Cholesky */
-  int stat_chol = gsl_linalg_cholesky_decomp(A);
+  int stat_chol = gsl_linalg_cholesky_decomp1(A);
 
   if(stat_chol == GSL_SUCCESS)
   {
@@ -390,7 +418,7 @@ gsl_linalg_cholesky_decomp2(gsl_matrix * A, gsl_vector * S)
         return status;
 
       /* compute Cholesky decomposition of diag(S) A diag(S) */
-      status = gsl_linalg_cholesky_decomp(A);
+      status = gsl_linalg_cholesky_decomp1(A);
       if (status)
         return status;
 
