@@ -52,7 +52,8 @@ main (void)
 
   fminimizer[0] = gsl_min_fminimizer_goldensection;
   fminimizer[1] = gsl_min_fminimizer_brent;
-  fminimizer[2] = 0;
+  fminimizer[2] = gsl_min_fminimizer_quad_golden;
+  fminimizer[3] = 0;
 
   F_cos = create_function (f_cos) ;
   F_func1 = create_function (func1) ;
@@ -111,8 +112,8 @@ test_f (const gsl_min_fminimizer_type * T,
       b = gsl_min_fminimizer_x_upper(s);
 
 #ifdef DEBUG
-      printf("%.12f %.18f %.12f %.18f %.12f %.18f\n", 
-             a, GSL_FN_EVAL(f, a), m, GSL_FN_EVAL(f, m), b, GSL_FN_EVAL(f, b));
+      printf("%.12f %.18f %.12f %.18f %.12f %.18f status=%d\n", 
+             a, GSL_FN_EVAL(f, a), m, GSL_FN_EVAL(f, m), b, GSL_FN_EVAL(f, b), status);
 #endif
 
       if (a > b)
