@@ -1,5 +1,7 @@
 static int
-iterate (void *vstate, gsl_multifit_function_fdf * fdf, gsl_vector * x, gsl_vector * f, gsl_matrix * J, gsl_vector * dx, int scale)
+iterate (void *vstate, const gsl_vector * swts,
+         gsl_multifit_function_fdf * fdf, gsl_vector * x,
+         gsl_vector * f, gsl_vector * dx, int scale)
 {
   lmder_state_t *state = (lmder_state_t *) vstate;
 
@@ -31,11 +33,6 @@ iterate (void *vstate, gsl_multifit_function_fdf * fdf, gsl_vector * x, gsl_vect
       return GSL_SUCCESS;
     }
 
-  /* Compute qtf = Q^T f */
-
-  gsl_vector_memcpy (qtf, f);
-  gsl_linalg_QR_QTvec (r, tau, qtf);
-
   /* Compute norm of scaled gradient */
 
   compute_gradient_direction (r, perm, qtf, diag, gradient);
@@ -80,7 +77,7 @@ lm_iteration:
   /* Evaluate function at x + p */
   /* return immediately if evaluation raised error */
   {
-    int status = GSL_MULTIFIT_FN_EVAL_F (fdf, x_trial, f_trial);
+    int status = gsl_multifit_eval_wf (fdf, x_trial, swts, f_trial);
     if (status)
       return status;
   }
@@ -182,11 +179,12 @@ lm_iteration:
       /* return immediately if evaluation raised error */
       {
         int status;
-        
+
+        /* compute Jacobian at new x and store in state->r */
         if (fdf->df)
-          status = GSL_MULTIFIT_FN_EVAL_DF (fdf, x_trial, J);
+          status = gsl_multifit_eval_wdf (fdf, x_trial, swts, r);
         else
-          status = gsl_multifit_fdfsolver_dif_df(x_trial, fdf, f_trial, J);
+          status = gsl_multifit_fdfsolver_dif_df(x_trial, swts, fdf, f_trial, r);
 
         if (status)
           return status;
@@ -201,13 +199,17 @@ lm_iteration:
 
       if (scale)
         {
-          update_diag (J, diag);
+          update_diag (r, diag);
         }
 
+      /* compute J = Q R P^T and qtf = Q^T f */
       {
         int signum;
-        gsl_matrix_memcpy (r, J);
+
+        gsl_matrix_memcpy(state->J, r);
         gsl_linalg_QRPT_decomp (r, tau, perm, &signum, work1);
+        gsl_vector_memcpy (qtf, f);
+        gsl_linalg_QR_QTvec (r, tau, qtf);
       }
       
       return GSL_SUCCESS;
