@@ -38,6 +38,7 @@ gsl_multifit_linear_alloc (const size_t nmax, const size_t pmax)
   w->pmax = pmax;                     /* max number of parameters */
   w->n = 0;
   w->p = 0;
+  w->rcond = 0.0;
 
   w->A = gsl_matrix_alloc (nmax, pmax);
 
@@ -95,21 +96,6 @@ gsl_multifit_linear_alloc (const size_t nmax, const size_t pmax)
       GSL_ERROR_VAL ("failed to allocate space for D", GSL_ENOMEM, 0);
     }
 
-  w->LTQR = gsl_matrix_alloc(pmax, pmax);
-  if (w->LTQR == 0)
-    {
-      gsl_multifit_linear_free(w);
-      GSL_ERROR_VAL ("failed to allocate space for LTQR", GSL_ENOMEM, 0);
-    }
-
-  w->LTtau = gsl_vector_alloc(pmax);
-
-  if (w->LTtau == 0)
-    {
-      gsl_multifit_linear_free(w);
-      GSL_ERROR_VAL ("failed to allocate space for LTtau", GSL_ENOMEM, 0);
-    }
-
   return w;
 }
 
@@ -139,12 +125,6 @@ gsl_multifit_linear_free (gsl_multifit_linear_workspace * w)
   if (w->D)
     gsl_vector_free (w->D);
 
-  if (w->LTQR)
-    gsl_matrix_free (w->LTQR);
-
-  if (w->LTtau)
-    gsl_vector_free (w->LTtau);
-
   free (w);
 }
 
