@@ -4,7 +4,7 @@
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or (at
+ * the Free Software Foundation; either version 3 of the License, or (at
  * your option) any later version.
  * 
  * This program is distributed in the hope that it will be useful, but
@@ -14,7 +14,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 /* Author:  G. Jungman */
@@ -96,7 +96,8 @@ gsl_sf_hydrogenicR_e(const int n, const int l,
     result->val  = W_val * lag.val;
     result->err  = W_val * lag.err + W_err * fabs(lag.val);
     result->err += 2.0 * GSL_DBL_EPSILON * fabs(result->val);
-    if (stat_lag == GSL_SUCCESS && stat_norm == GSL_SUCCESS) {
+    if ((l == 0 || (r > 0 && l > 0)) && lag.val != 0.0 
+        && stat_lag == GSL_SUCCESS && stat_norm == GSL_SUCCESS) {
       CHECK_UNDERFLOW(result);
     };
     return GSL_ERROR_SELECT_2(stat_lag, stat_norm);
