@@ -1,6 +1,5 @@
-/* Author:  G. Jungman
- * RCS:     $Id: gsl_sf.h,v 1.23 2001/08/23 04:54:50 jungman Exp $
- */
+/* Author:  G. Jungman */
+
 #ifndef __GSL_SF_H__
 #define __GSL_SF_H__
 
@@ -23,11 +22,13 @@
 #include <gsl/gsl_sf_fermi_dirac.h>
 #include <gsl/gsl_sf_gamma.h>
 #include <gsl/gsl_sf_gegenbauer.h>
+#include <gsl/gsl_sf_hermite.h>
 #include <gsl/gsl_sf_hyperg.h>
 #include <gsl/gsl_sf_laguerre.h>
 #include <gsl/gsl_sf_lambert.h>
 #include <gsl/gsl_sf_legendre.h>
 #include <gsl/gsl_sf_log.h>
+#include <gsl/gsl_sf_mathieu.h>
 #include <gsl/gsl_sf_pow_int.h>
 #include <gsl/gsl_sf_psi.h>
 #include <gsl/gsl_sf_synchrotron.h>
