@@ -69,8 +69,11 @@ int test_sf_check_result_relax(char * message_buff, gsl_sf_result r, double val,
 #define TEST_SF_TOLBAD  4
 #define TEST_SF_RETBAD  8
 #define TEST_SF_ERRBAD  16
+#define TEST_SF_ERRBIG  32
+#define TEST_SF_EXPBAD  64
 
 int test_sf (gsl_sf_result r, double val_in, double tol, int status, int expect_return, const char * desc);
+int test_sf_e10 (gsl_sf_result_e10 r, double val_in, int e10_in, double tol, int status, int expect_return, const char * desc);
 int test_sf_val (double val, double val_in, double tol, const char * desc);
 int test_sf_rlx (gsl_sf_result r, double val_in, double tol, int status, int expect_return, const char * desc);
 int test_sf_2 (gsl_sf_result r1, double val1, double tol1, gsl_sf_result r2, double val2, double tol2, int status, int expect_return, const char * desc);
@@ -78,6 +81,8 @@ int test_sf_sgn (gsl_sf_result r, double sgn, double val_in, double tol, double
 
 #define TEST_SF(stat, func, args, val_in, tol, expect_return) { int status = func args; stat += test_sf(r, val_in, tol, status, expect_return, #func #args); }
 
+#define TEST_SF_E10(stat, func, args, val_in, e10_in, tol, expect_return) { int status = func args; stat += test_sf_e10(re, val_in, e10_in, tol, status, expect_return, #func #args); }
+
 #define TEST_SF_VAL(stat, func, args, val_in, tol) { double val = func args; stat += test_sf_val(val, val_in, tol, #func #args); }
 
 #define TEST_SF_RLX(stat, func, args, val_in, tol, expect_return) { int status = func args; stat += test_sf_rlx(r, val_in, tol, status, expect_return, #func #args); }
@@ -94,6 +99,7 @@ int test_coulomb(void);
 int test_dilog(void);
 int test_gamma(void);
 int test_mathieu(void);
+int test_hermite(void);
 int test_hyperg(void);
 int test_legendre(void);
 
